/******************************************************************************

 @file  hal_appasrt.h

 @brief This module defines the OSAL application assert function

 Group: WCS, LPC, BTS
 Target Device: cc13x0

 ******************************************************************************
 
 Copyright (c) 2014-2022, Texas Instruments Incorporated
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 *  Redistributions of source code must retain the above copyright
    notice, this list of conditions and the following disclaimer.

 *  Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in the
    documentation and/or other materials provided with the distribution.

 *  Neither the name of Texas Instruments Incorporated nor the names of
    its contributors may be used to endorse or promote products derived
    from this software without specific prior written permission.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 ******************************************************************************
 
 
 *****************************************************************************/

#ifdef __cplusplus
extern "C"
{
#endif

/*********************************************************************
 * INCLUDES
 */
 
#include "appasrtintf.h"
#include "hal_types.h"

/*********************************************************************
 * FUNCTIONS
 */

/*********************************************************************
 * @brief   Register application assert handler function pointer for use on
 *          stack side.
 *
 * @param  *pFptr Pointer to app assert handler function
 *
 * @return  APPASRTINTF_SUCCESS if registration succeeds. APPASRTINTF_FAILURE, 
 *          otherwise.
 */
extern uint8_t HAL_APPASRT_register(APPASRTINTF_assrtHndlerFunc_t *pFptr);

/**
 * @brief   Wrapper function call to application assert via funciton pointer.
 *
 * @param    none
 *
 * @return  none
 */
extern void HAL_APPASRT_callAssrtHanlder(void);

/*********************************************************************
*********************************************************************/

#ifdef __cplusplus
}
#endif
